@@ -8,8 +8,8 @@
 
 #include "eventviews_export.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <AkonadiCore/Item>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/Item>
 #include <KCalendarCore/Incidence>
 
 #include <QColor>
