@@ -7,14 +7,13 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_EVENTVIEW_H
-#define EVENTVIEWS_EVENTVIEW_H
+#pragma once
 
 #include "eventviews_export.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Incidence>
 #include <KCalendarCore/Todo>
@@ -24,6 +23,8 @@
 #include <QSet>
 #include <QWidget>
 
+#include <memory>
+
 namespace CalendarSupport
 {
 class CollectionSelection;
@@ -107,7 +108,7 @@ public:
     /**
      * Destructor. Views will do view-specific cleanups here.
      */
-    ~EventView();
+    ~EventView() override;
 
     virtual void setCalendar(const Akonadi::ETMCalendar::Ptr &cal);
 
@@ -250,7 +251,7 @@ public:
     Q_REQUIRED_RESULT QDateTime actualStartDateTime() const;
     Q_REQUIRED_RESULT QDateTime actualEndDateTime() const;
 
-    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date);
+    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalendarCore::Incidence::Ptr &incidence, QDate date);
 
     /**
       Handles key events, opens the new event dialog when enter is pressed, activates type ahead.
@@ -491,9 +492,8 @@ protected:
     virtual void handleBackendError(const QString &error);
 
 private:
-    EventViewPrivate *const d_ptr;
+    std::unique_ptr<EventViewPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(EventView)
 };
 }
 
-#endif
