@@ -30,7 +30,7 @@
 using namespace EventViews;
 
 JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
-    : QFrame(parent)
+    : QWidget(parent)
     , mCalendar(calendar)
 {
     auto layout = new QVBoxLayout(this);
@@ -38,9 +38,7 @@ JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWid
     layout->setSpacing(0);
 }
 
-JournalDateView::~JournalDateView()
-{
-}
+JournalDateView::~JournalDateView() = default;
 
 void JournalDateView::setDate(QDate date)
 {
@@ -81,9 +79,9 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
     connect(entry, &JournalFrame::editIncidence, this, &JournalDateView::editIncidence);
     connect(entry, &JournalFrame::incidenceSelected, this, &JournalDateView::incidenceSelected);
     connect(entry,
-            QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalFrame::printJournal),
+            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalFrame::printJournal),
             this,
-            QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalDateView::printJournal));
+            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalDateView::printJournal));
 }
 
 Akonadi::Item::List JournalDateView::journals() const
@@ -176,7 +174,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mPrintButton->setToolTip(i18n("Print this journal entry"));
     mPrintButton->setWhatsThis(i18n("Opens a print dialog for this journal entry"));
     buttonsLayout->addWidget(mPrintButton);
-    connect(mPrintButton, &QPushButton::clicked, this, QOverload<>::of(&JournalFrame::printJournal));
+    connect(mPrintButton, &QPushButton::clicked, this, qOverload<>(&JournalFrame::printJournal));
 
     mPrintPreviewButton = new QPushButton(this);
     mPrintPreviewButton->setText(i18n("Print preview"));
@@ -195,9 +193,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mBrowser->setStyleSheet(QStringLiteral("QFrame { border: 0px solid white } "));
 }
 
-JournalFrame::~JournalFrame()
-{
-}
+JournalFrame::~JournalFrame() = default;
 
 bool JournalFrame::eventFilter(QObject *object, QEvent *event)
 {
