@@ -180,12 +180,15 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     font.setPointSize(15);
     p->setFont(font);
     const int dayLabelsHeight = 20;
+    const auto dayInMonth = mMonthView->averageDate();
     p->drawText(QRect(0,
                       0, // top right
                       static_cast<int>(mScene->sceneRect().width()),
                       static_cast<int>(mScene->headerHeight() - dayLabelsHeight)),
                 Qt::AlignCenter,
-                mMonthView->averageDate().toString(QStringLiteral("MMMM yyyy")));
+                QStringLiteral("%1 %2")
+                    .arg(QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat))
+                    .arg(dayInMonth.year()));
 
     font.setPointSize(dayLabelsHeight - 10);
     p->setFont(font);
@@ -697,7 +700,7 @@ void MonthScene::selectItem(MonthItem *item)
       }
 
       I commented the above code so it's possible to selected a selected item.
-      korg-mobile needs that, otherwise clicking on a selected item wont bring the editor up.
+      korg-mobile needs that, otherwise clicking on a selected item won't bring the editor up.
       Another solution would be to have two Q_SIGNALS: incidenceSelected() and incidenceClicked()
     */
 
