@@ -12,7 +12,7 @@
 #include "monthscene.h"
 #include "prefs.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
@@ -265,7 +265,7 @@ QDateTime MonthView::selectionStart() const
     if (d->scene->selectedCell()) {
         return QDateTime(d->scene->selectedCell()->date().startOfDay());
     } else {
-        return QDateTime();
+        return {};
     }
 }
 
