@@ -25,7 +25,7 @@ TimelineItem::TimelineItem(const Akonadi::ETMCalendar::Ptr &calendar, uint index
     , mIndex(index)
 {
     mModel->removeRow(mIndex);
-    auto *dummyItem = new QStandardItem;
+    auto dummyItem = new QStandardItem;
     dummyItem->setData(KGantt::TypeTask, KGantt::ItemTypeRole);
     mModel->insertRow(mIndex, dummyItem);
 }
@@ -45,16 +45,15 @@ void TimelineItem::insertIncidence(const Akonadi::Item &aitem, const QDateTime &
         end = end.addDays(1);
     }
 
-    typedef QList<QStandardItem *> ItemList;
+    using ItemList = QList<QStandardItem *>;
     ItemList list = mItemMap.value(aitem.id());
     for (ItemList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
-        if (static_cast<TimelineSubItem *>(*it)->startTime() == start
-            && static_cast<TimelineSubItem *>(*it)->endTime() == end) {
+        if (static_cast<TimelineSubItem *>(*it)->startTime() == start && static_cast<TimelineSubItem *>(*it)->endTime() == end) {
             return;
         }
     }
 
-    auto *item = new TimelineSubItem(mCalendar, aitem, this);
+    auto item = new TimelineSubItem(mCalendar, aitem, this);
 
     item->setStartTime(start);
     item->setOriginalStart(start);
@@ -78,7 +77,7 @@ void TimelineItem::removeIncidence(const Akonadi::Item &incidence)
 
 void TimelineItem::moveItems(const Akonadi::Item &incidence, int delta, int duration)
 {
-    typedef QList<QStandardItem *> ItemList;
+    using ItemList = QList<QStandardItem *>;
     ItemList list = mItemMap.value(incidence.id());
     const ItemList::ConstIterator end(list.constEnd());
     for (ItemList::ConstIterator it = list.constBegin(); it != end; ++it) {
@@ -108,9 +107,7 @@ TimelineSubItem::TimelineSubItem(const Akonadi::ETMCalendar::Ptr &calendar, cons
     }
 }
 
-TimelineSubItem::~TimelineSubItem()
-{
-}
+TimelineSubItem::~TimelineSubItem() = default;
 
 void TimelineSubItem::setStartTime(const QDateTime &dt)
 {
@@ -140,8 +137,9 @@ void TimelineSubItem::updateToolTip()
 
     mToolTipNeedsUpdate = false;
 
-    setData(IncidenceFormatter::toolTipStr(
-                CalendarSupport::displayName(mCalendar.data(), mIncidence.parentCollection()),
-                CalendarSupport::incidence(mIncidence),
-                originalStart().date(), true), Qt::ToolTipRole);
+    setData(IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), mIncidence.parentCollection()),
+                                           CalendarSupport::incidence(mIncidence),
+                                           originalStart().date(),
+                                           true),
+            Qt::ToolTipRole);
 }
