@@ -7,7 +7,7 @@
 #include "calendarview_debug.h"
 #include "incidencetreemodel_p.h"
 
-#include <AkonadiCore/EntityTreeModel>
+#include <Akonadi/EntityTreeModel>
 
 using namespace Akonadi;
 QDebug operator<<(QDebug s, const Node::Ptr &node);
@@ -43,7 +43,7 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
     PreNode::List remainingNodes = nodes;
 
     while (prenodeByUid.count() < count) {
-        const auto preSize = prenodeByUid.count(); // this saves us from infinit looping if the parent doesn't exist
+        const auto preSize = prenodeByUid.count(); // this saves us from infinite looping if the parent doesn't exist
         for (const PreNode::Ptr &node : nodes) {
             Q_ASSERT(node);
             const QString uid = node->incidence->instanceIdentifier();
@@ -71,14 +71,14 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
     return sorted;
 }
 
-IncidenceTreeModel::Private::Private(IncidenceTreeModel *qq, const QStringList &mimeTypes)
+IncidenceTreeModelPrivate::IncidenceTreeModelPrivate(IncidenceTreeModel *qq, const QStringList &mimeTypes)
     : QObject()
     , m_mimeTypes(mimeTypes)
     , q(qq)
 {
 }
 
-int IncidenceTreeModel::Private::rowForNode(const Node::Ptr &node) const
+int IncidenceTreeModelPrivate::rowForNode(const Node::Ptr &node) const
 {
     // Returns it's row number
     const int row = node->parentNode ? node->parentNode->directChilds.indexOf(node) : m_toplevelNodeList.indexOf(node);
@@ -86,7 +86,7 @@ int IncidenceTreeModel::Private::rowForNode(const Node::Ptr &node) const
     return row;
 }
 
-void IncidenceTreeModel::Private::assert_and_dump(bool condition, const QString &message)
+void IncidenceTreeModelPrivate::assert_and_dump(bool condition, const QString &message)
 {
     if (!condition) {
         qCCritical(CALENDARVIEW_LOG) << "This should never happen: " << message;
@@ -95,14 +95,14 @@ void IncidenceTreeModel::Private::assert_and_dump(bool condition, const QString
     }
 }
 
-void IncidenceTreeModel::Private::dumpTree()
+void IncidenceTreeModelPrivate::dumpTree()
 {
     for (const Node::Ptr &node : std::as_const(m_toplevelNodeList)) {
         qCDebug(CALENDARVIEW_LOG) << node;
     }
 }
 
-QModelIndex IncidenceTreeModel::Private::indexForNode(const Node::Ptr &node) const
+QModelIndex IncidenceTreeModelPrivate::indexForNode(const Node::Ptr &node) const
 {
     if (!node) {
         return {};
@@ -113,7 +113,7 @@ QModelIndex IncidenceTreeModel::Private::indexForNode(const Node::Ptr &node) con
     return q->createIndex(row, 0, node.data());
 }
 
-void IncidenceTreeModel::Private::reset(bool silent)
+void IncidenceTreeModelPrivate::reset(bool silent)
 {
     if (!silent) {
         q->beginResetModel();
@@ -137,12 +137,12 @@ void IncidenceTreeModel::Private::reset(bool silent)
     }
 }
 
-void IncidenceTreeModel::Private::onHeaderDataChanged(Qt::Orientation orientation, int first, int last)
+void IncidenceTreeModelPrivate::onHeaderDataChanged(Qt::Orientation orientation, int first, int last)
 {
     Q_EMIT q->headerDataChanged(orientation, first, last);
 }
 
-void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
+void IncidenceTreeModelPrivate::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
 {
     Q_ASSERT(begin.isValid());
     Q_ASSERT(end.isValid());
@@ -253,7 +253,7 @@ void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const
     }
 }
 
-void IncidenceTreeModel::Private::onRowsAboutToBeInserted(const QModelIndex &parent, int, int)
+void IncidenceTreeModelPrivate::onRowsAboutToBeInserted(const QModelIndex &parent, int, int)
 {
     // We are a reparenting proxy, the source proxy is flat
     Q_ASSERT(!parent.isValid());
@@ -262,7 +262,7 @@ void IncidenceTreeModel::Private::onRowsAboutToBeInserted(const QModelIndex &par
     // parent yet.
 }
 
-PreNode::Ptr IncidenceTreeModel::Private::prenodeFromSourceRow(int row) const
+PreNode::Ptr IncidenceTreeModelPrivate::prenodeFromSourceRow(int row) const
 {
     PreNode::Ptr node = PreNode::Ptr(new PreNode());
     node->sourceIndex = q->sourceModel()->index(row, 0, QModelIndex());
@@ -272,7 +272,7 @@ PreNode::Ptr IncidenceTreeModel::Private::prenodeFromSourceRow(int row) const
 
     if (!item.isValid()) {
         // It's a Collection, ignore that, we only want items.
-        return PreNode::Ptr();
+        return {};
     }
 
     node->item = item;
@@ -282,7 +282,7 @@ PreNode::Ptr IncidenceTreeModel::Private::prenodeFromSourceRow(int row) const
     return node;
 }
 
-void IncidenceTreeModel::Private::onRowsInserted(const QModelIndex &parent, int begin, int end)
+void IncidenceTreeModelPrivate::onRowsInserted(const QModelIndex &parent, int begin, int end)
 {
     // QElapsedTimer timer;
     // timer.start();
@@ -312,7 +312,7 @@ void IncidenceTreeModel::Private::onRowsInserted(const QModelIndex &parent, int
     // qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to insert " << end-begin+1;
 }
 
-void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool silent)
+void IncidenceTreeModelPrivate::insertNode(const PreNode::Ptr &prenode, bool silent)
 {
     KCalendarCore::Incidence::Ptr incidence = prenode->incidence;
     Akonadi::Item item = prenode->item;
@@ -382,11 +382,11 @@ void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool s
     // Are we a parent?
     if (m_waitingForParent.contains(node->uid)) {
         Q_ASSERT(m_waitingForParent.count(node->uid) > 0);
-        const QList<Node::Ptr> childs = m_waitingForParent.values(node->uid);
+        const QList<Node::Ptr> children = m_waitingForParent.values(node->uid);
         m_waitingForParent.remove(node->uid);
-        Q_ASSERT(!childs.isEmpty());
+        Q_ASSERT(!children.isEmpty());
 
-        for (const Node::Ptr &child : childs) {
+        for (const Node::Ptr &child : children) {
             const int fromRow = m_toplevelNodeList.indexOf(child);
             Q_ASSERT(fromRow != -1);
             const QModelIndex toParent = indexForNode(node);
@@ -414,8 +414,8 @@ void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool s
     }
 }
 
-// Sorts childs first parents last
-Node::List IncidenceTreeModel::Private::sorted(const Node::List &nodes) const
+// Sorts children first parents last
+Node::List IncidenceTreeModelPrivate::sorted(const Node::List &nodes) const
 {
     if (nodes.isEmpty()) {
         return nodes;
@@ -432,7 +432,7 @@ Node::List IncidenceTreeModel::Private::sorted(const Node::List &nodes) const
     return sorted;
 }
 
-void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
+void IncidenceTreeModelPrivate::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
 {
     // QElapsedTimer timer;
     // timer.start();
@@ -458,12 +458,12 @@ void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &pare
         nodesToRemove << node;
     }
 
-    // We want to remove childs first, to avoid row moving
+    // We want to remove children first, to avoid row moving
     const Node::List nodesToRemoveSorted = sorted(nodesToRemove);
 
     for (const Node::Ptr &node : nodesToRemoveSorted) {
         // Go ahead and remove it now. We don't do it in ::onRowsRemoved(), because
-        // while unparenting childs with moveRows() the view might call data() on the
+        // while unparenting children with moveRows() the view might call data() on the
         // item that is already removed from ETM.
         removeNode(node);
         // qCDebug(CALENDARVIEW_LOG) << "Just removed a node, here's the tree";
@@ -474,7 +474,7 @@ void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &pare
     // qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to remove " << end-begin+1;
 }
 
-void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
+void IncidenceTreeModelPrivate::removeNode(const Node::Ptr &node)
 {
     Q_ASSERT(node);
     // qCDebug(CALENDARVIEW_LOG) << "Dealing with parent: " << node->id << node.data()
@@ -482,7 +482,7 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
 
     // First, unparent the children
     if (!node->directChilds.isEmpty()) {
-        const Node::List childs = node->directChilds;
+        const Node::List children = node->directChilds;
         const QModelIndex fromParent = indexForNode(node);
         Q_ASSERT(fromParent.isValid());
         //    const int firstSourceRow = 0;
@@ -492,7 +492,7 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
         //                  /**toParent is root*/QModelIndex(), toRow );
         q->beginResetModel();
         node->directChilds.clear();
-        for (const Node::Ptr &child : childs) {
+        for (const Node::Ptr &child : children) {
             // qCDebug(CALENDARVIEW_LOG) << "Dealing with child: " << child.data() << child->uid;
             m_toplevelNodeList.append(child);
             child->parentNode = Node::Ptr();
@@ -529,7 +529,7 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
     m_removedNodes << node.data();
 }
 
-void IncidenceTreeModel::Private::onRowsRemoved(const QModelIndex &parent, int begin, int end)
+void IncidenceTreeModelPrivate::onRowsRemoved(const QModelIndex &parent, int begin, int end)
 {
     Q_UNUSED(parent)
     Q_UNUSED(begin)
@@ -537,88 +537,88 @@ void IncidenceTreeModel::Private::onRowsRemoved(const QModelIndex &parent, int b
     // Nothing to do here, see comment on ::onRowsAboutToBeRemoved()
 }
 
-void IncidenceTreeModel::Private::onModelAboutToBeReset()
+void IncidenceTreeModelPrivate::onModelAboutToBeReset()
 {
     q->beginResetModel();
 }
 
-void IncidenceTreeModel::Private::onModelReset()
+void IncidenceTreeModelPrivate::onModelReset()
 {
     reset(/**silent=*/false);
     q->endResetModel();
 }
 
-void IncidenceTreeModel::Private::onLayoutAboutToBeChanged()
+void IncidenceTreeModelPrivate::onLayoutAboutToBeChanged()
 {
     Q_ASSERT(q->persistentIndexList().isEmpty());
     Q_EMIT q->layoutAboutToBeChanged();
 }
 
-void IncidenceTreeModel::Private::onLayoutChanged()
+void IncidenceTreeModelPrivate::onLayoutChanged()
 {
     reset(/**silent=*/true);
     Q_ASSERT(q->persistentIndexList().isEmpty());
     Q_EMIT q->layoutChanged();
 }
 
-void IncidenceTreeModel::Private::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
+void IncidenceTreeModelPrivate::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
 {
     // Not implemented yet
     Q_ASSERT(false);
 }
 
-void IncidenceTreeModel::Private::setSourceModel(QAbstractItemModel *model)
+void IncidenceTreeModelPrivate::setSourceModel(QAbstractItemModel *model)
 {
     q->beginResetModel();
 
     if (q->sourceModel()) {
-        disconnect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModel::Private::onDataChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModelPrivate::onDataChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModel::Private::onHeaderDataChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModelPrivate::onHeaderDataChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModel::Private::onRowsInserted);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModelPrivate::onRowsInserted);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModel::Private::onRowsRemoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModelPrivate::onRowsRemoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModel::Private::onRowsMoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModelPrivate::onRowsMoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModel::Private::onRowsAboutToBeInserted);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModelPrivate::onRowsAboutToBeInserted);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModel::Private::onRowsAboutToBeRemoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModelPrivate::onRowsAboutToBeRemoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModel::Private::onModelAboutToBeReset);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModelPrivate::onModelAboutToBeReset);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModel::Private::onModelReset);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModelPrivate::onModelReset);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModel::Private::onLayoutAboutToBeChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModelPrivate::onLayoutAboutToBeChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModel::Private::onLayoutChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModelPrivate::onLayoutChanged);
     }
 
     q->QAbstractProxyModel::setSourceModel(model);
 
     if (q->sourceModel()) {
-        connect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModel::Private::onDataChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModelPrivate::onDataChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModel::Private::onHeaderDataChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModelPrivate::onHeaderDataChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModel::Private::onRowsAboutToBeInserted);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModelPrivate::onRowsAboutToBeInserted);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModel::Private::onRowsInserted);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModelPrivate::onRowsInserted);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModel::Private::onRowsAboutToBeRemoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModelPrivate::onRowsAboutToBeRemoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModel::Private::onRowsRemoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModelPrivate::onRowsRemoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModel::Private::onRowsMoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModelPrivate::onRowsMoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModel::Private::onModelAboutToBeReset);
+        connect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModelPrivate::onModelAboutToBeReset);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModel::Private::onModelReset);
+        connect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModelPrivate::onModelReset);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModel::Private::onLayoutAboutToBeChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModelPrivate::onLayoutAboutToBeChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModel::Private::onLayoutChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModelPrivate::onLayoutChanged);
     }
 
     reset(/**silent=*/true);
@@ -627,28 +627,25 @@ void IncidenceTreeModel::Private::setSourceModel(QAbstractItemModel *model)
 
 IncidenceTreeModel::IncidenceTreeModel(QObject *parent)
     : QAbstractProxyModel(parent)
-    , d(new Private(this, QStringList()))
+    , d(new IncidenceTreeModelPrivate(this, QStringList()))
 {
     setObjectName(QStringLiteral("IncidenceTreeModel"));
 }
 
 IncidenceTreeModel::IncidenceTreeModel(const QStringList &mimeTypes, QObject *parent)
     : QAbstractProxyModel(parent)
-    , d(new Private(this, mimeTypes))
+    , d(new IncidenceTreeModelPrivate(this, mimeTypes))
 {
     setObjectName(QStringLiteral("IncidenceTreeModel"));
 }
 
-IncidenceTreeModel::~IncidenceTreeModel()
-{
-    delete d;
-}
+IncidenceTreeModel::~IncidenceTreeModel() = default;
 
 QVariant IncidenceTreeModel::data(const QModelIndex &index, int role) const
 {
     Q_ASSERT(index.isValid());
     if (!index.isValid() || !sourceModel()) {
-        return QVariant();
+        return {};
     }
 
     QModelIndex sourceIndex = mapToSource(index);
@@ -697,14 +694,14 @@ QModelIndex IncidenceTreeModel::mapFromSource(const QModelIndex &sourceIndex) co
     }
 
     if (!sourceModel()) {
-        return QModelIndex();
+        return {};
     }
     Q_ASSERT(sourceIndex.column() < sourceModel()->columnCount());
     Q_ASSERT(sourceModel() == sourceIndex.model());
     const Akonadi::Item::Id id = sourceIndex.data(Akonadi::EntityTreeModel::ItemIdRole).toLongLong();
 
     if (id == -1 || !d->m_nodeMap.contains(id)) {
-        return QModelIndex();
+        return {};
     }
 
     const Node::Ptr node = d->m_nodeMap.value(id);
@@ -741,7 +738,7 @@ QModelIndex IncidenceTreeModel::mapToSource(const QModelIndex &proxyIndex) const
     if (!index.isValid()) {
         qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::mapToSource(): sourceModelIndex is invalid";
         Q_ASSERT(false);
-        return QModelIndex();
+        return {};
     }
     Q_ASSERT(index.model() == sourceModel());
 
@@ -761,11 +758,11 @@ QModelIndex IncidenceTreeModel::parent(const QModelIndex &child) const
     Node *childNode = reinterpret_cast<Node *>(child.internalPointer());
     if (d->m_removedNodes.contains(childNode)) {
         qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::parent() Node already removed.";
-        return QModelIndex();
+        return {};
     }
 
     if (!childNode->parentNode) {
-        return QModelIndex();
+        return {};
     }
 
     const QModelIndex parentIndex = d->indexForNode(childNode->parentNode);
@@ -773,7 +770,7 @@ QModelIndex IncidenceTreeModel::parent(const QModelIndex &child) const
     if (!parentIndex.isValid()) {
         qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::parent(): proxyModelIndex is invalid.";
         Q_ASSERT(false);
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(parentIndex.model() == this);
@@ -805,7 +802,7 @@ QModelIndex IncidenceTreeModel::index(int row, int column, const QModelIndex &pa
         if (row >= parentNode->directChilds.count()) {
             qCCritical(CALENDARVIEW_LOG) << "IncidenceTreeModel::index() row=" << row << "; column=" << column;
             Q_ASSERT(false);
-            return QModelIndex();
+            return {};
         }
 
         return createIndex(row, column, parentNode->directChilds.at(row).data());
