@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARVIEWS_TODOVIEWQUICKADDLINE_H
-#define CALENDARVIEWS_TODOVIEWQUICKADDLINE_H
+#pragma once
 
 #include <KLineEdit>
 
@@ -17,9 +16,7 @@ class TodoViewQuickAddLine : public KLineEdit
 
 public:
     explicit TodoViewQuickAddLine(QWidget *parent);
-    ~TodoViewQuickAddLine() override
-    {
-    }
+    ~TodoViewQuickAddLine() override = default;
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
@@ -36,4 +33,3 @@ private:
     QString mClickMessage;
 };
 
-#endif
