@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class CreateColorGui_test : public QWidget
     Q_OBJECT
 public:
     explicit CreateColorGui_test(QWidget *parent = nullptr);
-    ~CreateColorGui_test();
+    ~CreateColorGui_test() override;
 
 private:
     void createListWidgetItem();
